log_asserts

Attribute Macro log_asserts 

#[log_asserts]
Rewrites standard Rust assertions in a function body into Allure assertion log steps.

This is useful for helper functions that are not already annotated with #[allure_test] or #[step].